.. :changelog:

History
=======

1.1.0
-----

* Add name to authenticate url
* Add support for Django 1.11 and Python 3.6

1.0.1
-----

* Unicode first

1.0.0
-----

* Add support for Django 1.10

0.4.0
-----

* Change data for HMAC-MD5 per Freshdesk's change.

0.3.0
-----

* Add Tox environments for Django 1.8 using Python 2.7, 3.3, 3.4

0.2.2
-----

* Fix Django version compatibility. Django 1.5 not supported anymore.

0.2.1
-----

* Username as default if not first and last name defined

0.1.4
-----

* Serveral fixes and updated doc

0.1.0
-----

* Initial application
